# 
# The program was written or based on one written in 2004 by Morgan Ames.
# http://www.ocf.berkeley.edu/~morganya
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the Creative Commons Attribution-NonCommercial 
# License. 
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE (as described by
# the GNU General Public License at http://www.gnu.org/licenses/gpl.html). 
#
# To view a copy of the Creative Commons Attribution-NonCommercial license, 
# visit http://creativecommons.org/licenses/by-nc/2.0/ or send a letter to 
# Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.

from smtplib import SMTP

no_reply_email = 'no-reply@ucbd.org'
mailserver = 'mail.ocf.berkeley.edu'

#~~~~~~~~~~~~~~~~~~ EMAILERS ~~~~~~~~~~~~~~~~~~~#

def valid_email(eml):
  """Return 1 if eml has an '@', 0 otherwise.
  """
  if eml.find('@') < 0:
    return 0
  else:
    return 1


def send(msg, sender, recipients):
  """Send msg to list of specified recipients, giving 'sender' as the sender.
     If 'sender' is not recognized by SMTP as valid, return a list
     of errors.  Else, return an empty list.
  """
  s = SMTP(mailserver)
  errors = []
  try:
    email = "From: " + sender + "\r\nTo: " + ', '.join(recipients) + \
            "\r\n" + msg + "\n\n\n\n"
    s.sendmail(sender, recipients, email)
  except:
    errors.append("Error - I can't verify that the e-mail address '" + sender + "' exists!")
  s.close()
  return errors

def parse_send(dict):
  sender = dict.get('sender', no_reply_email)
  recipients = map(strp, dict.get('recipients', '').replace(';', ',').split(','));
  msg = dict.get('msg', '')
  if 'subject' in dict:
    msg = "Subject: " + dict['subject'] + '\r\n' + msg

  if recipients and valid_email(sender):
    print "Sending from", sender, "<br>"
    print "Sending to", (', '.join(recipients)), "<br>"
    errors = send(msg, sender, recipients)
    if errors:
      print errors
    else:
      print "Send was successful."
  else:
    print "Either sender or recipients (or both) was not valid.  Back up and try again."


def strp(str):
  return str.strip()


def send_form():
  print '''
<html>
<body>
<center>
<form action="mailer.cgi" method="post">
<table>
<tr>
  <td align="right">From:</td>
  <td><input type="text" name="sender"> <font size="-1">(one email only)</font></td>
</tr>
<tr>
  <td align="right">To:</td>
  <td><input type="text" name="recipients" size="40"> <font size="-1">(separate by commas)</font></td>
</tr>
<tr>
  <td align="right">Subject:</td>
  <td><input type="text" name="subject" size="40"></td>
</tr>
<tr>
  <td colspan="2">
    <textarea name="msg" rows=20 cols=80></textarea><br>
    <input type="submit">
  </td>
</tr>
</table>
</form>
</body>
</html>'''
